==> tagainijisho_0.9.2.orig.tar.gz: tagainijisho-0.9.2/3rdparty/JMdictDescs.cc <==
QT_TRANSLATE_NOOP("JMdictLongDescs", "martial arts term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "rude or X-rated term (not displayed in educational software)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "abbreviation");
QT_TRANSLATE_NOOP("JMdictLongDescs", "adjective (keiyoushi)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "adjectival nouns or quasi-adjectives (keiyodoshi)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "nouns which may take the genitive case particle `no'");
QT_TRANSLATE_NOOP("JMdictLongDescs", "pre-noun adjectival (rentaishi)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "`taru' adjective");
QT_TRANSLATE_NOOP("JMdictLongDescs", "noun or verb acting prenominally");
QT_TRANSLATE_NOOP("JMdictLongDescs", "former adjective classification (being removed)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "adverb (fukushi)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "adverb taking the `to' particle");
QT_TRANSLATE_NOOP("JMdictLongDescs", "archaism");
QT_TRANSLATE_NOOP("JMdictLongDescs", "ateji (phonetic) reading");
QT_TRANSLATE_NOOP("JMdictLongDescs", "auxiliary");
QT_TRANSLATE_NOOP("JMdictLongDescs", "auxiliary verb");
QT_TRANSLATE_NOOP("JMdictLongDescs", "auxiliary adjective");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Buddhist term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "chemistry term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "children's language");
QT_TRANSLATE_NOOP("JMdictLongDescs", "colloquialism");
QT_TRANSLATE_NOOP("JMdictLongDescs", "computer terminology");
QT_TRANSLATE_NOOP("JMdictLongDescs", "conjunction");
QT_TRANSLATE_NOOP("JMdictLongDescs", "counter");
QT_TRANSLATE_NOOP("JMdictLongDescs", "derogatory");
QT_TRANSLATE_NOOP("JMdictLongDescs", "exclusively kanji");
QT_TRANSLATE_NOOP("JMdictLongDescs", "exclusively kana");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Expressions (phrases, clauses, etc.)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "familiar language");
QT_TRANSLATE_NOOP("JMdictLongDescs", "female term or language");
QT_TRANSLATE_NOOP("JMdictLongDescs", "food term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "geometry term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "gikun (meaning as reading)  or jukujikun (special kanji reading)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "honorific or respectful (sonkeigo) language");
QT_TRANSLATE_NOOP("JMdictLongDescs", "humble (kenjougo) language");
QT_TRANSLATE_NOOP("JMdictLongDescs", "word containing irregular kanji usage");
QT_TRANSLATE_NOOP("JMdictLongDescs", "idiomatic expression");
QT_TRANSLATE_NOOP("JMdictLongDescs", "word containing irregular kana usage");
QT_TRANSLATE_NOOP("JMdictLongDescs", "interjection (kandoushi)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "irregular okurigana usage");
QT_TRANSLATE_NOOP("JMdictLongDescs", "irregular verb");
QT_TRANSLATE_NOOP("JMdictLongDescs", "linguistics terminology");
QT_TRANSLATE_NOOP("JMdictLongDescs", "manga slang");
QT_TRANSLATE_NOOP("JMdictLongDescs", "male term or language");
QT_TRANSLATE_NOOP("JMdictLongDescs", "male slang");
QT_TRANSLATE_NOOP("JMdictLongDescs", "mathematics");
QT_TRANSLATE_NOOP("JMdictLongDescs", "military");
QT_TRANSLATE_NOOP("JMdictLongDescs", "noun (common) (futsuumeishi)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "adverbial noun (fukushitekimeishi)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "noun, used as a suffix");
QT_TRANSLATE_NOOP("JMdictLongDescs", "noun, used as a prefix");
QT_TRANSLATE_NOOP("JMdictLongDescs", "noun (temporal) (jisoumeishi)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "numeric");
QT_TRANSLATE_NOOP("JMdictLongDescs", "word containing out-dated kanji");
QT_TRANSLATE_NOOP("JMdictLongDescs", "obsolete term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "obscure term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "out-dated or obsolete kana usage");
QT_TRANSLATE_NOOP("JMdictLongDescs", "onomatopoeic or mimetic word");
QT_TRANSLATE_NOOP("JMdictLongDescs", "pronoun");
QT_TRANSLATE_NOOP("JMdictLongDescs", "poetical term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "polite (teineigo) language");
QT_TRANSLATE_NOOP("JMdictLongDescs", "prefix");
QT_TRANSLATE_NOOP("JMdictLongDescs", "proverb");
QT_TRANSLATE_NOOP("JMdictLongDescs", "particle");
QT_TRANSLATE_NOOP("JMdictLongDescs", "physics terminology");
QT_TRANSLATE_NOOP("JMdictLongDescs", "rare");
QT_TRANSLATE_NOOP("JMdictLongDescs", "sensitive");
QT_TRANSLATE_NOOP("JMdictLongDescs", "slang");
QT_TRANSLATE_NOOP("JMdictLongDescs", "suffix");
QT_TRANSLATE_NOOP("JMdictLongDescs", "word usually written using kanji alone");
QT_TRANSLATE_NOOP("JMdictLongDescs", "word usually written using kana alone");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Ichidan verb");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb with 'u' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Yondan verb with `hu/fu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Yondan verb with `ru' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb (not completely classified)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb - -aru special class");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `bu' ending");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `gu' ending");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `ku' ending");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb - Iku/Yuku special class");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `mu' ending");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `nu' ending");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `ru' ending");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `ru' ending (irregular verb)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `su' ending");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `tsu' ending");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `u' ending");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `u' ending (special class)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb - Uru old class verb (old form of Eru)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `zu' ending");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Ichidan verb - zuru verb (alternative form of -jiru verbs)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "intransitive verb");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Kuru verb - special class");
QT_TRANSLATE_NOOP("JMdictLongDescs", "irregular nu verb");
QT_TRANSLATE_NOOP("JMdictLongDescs", "irregular ru verb, plain form ends with -ri");
QT_TRANSLATE_NOOP("JMdictLongDescs", "noun or participle which takes the aux. verb suru");
QT_TRANSLATE_NOOP("JMdictLongDescs", "su verb - precursor to the modern suru");
QT_TRANSLATE_NOOP("JMdictLongDescs", "suru verb - special class");
QT_TRANSLATE_NOOP("JMdictLongDescs", "suru verb - irregular");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Kyoto-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Osaka-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Kansai-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Kantou-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Tosa-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Touhoku-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Tsugaru-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Kyuushuu-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Ryuukyuu-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nagano-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "transitive verb");
QT_TRANSLATE_NOOP("JMdictLongDescs", "vulgar expression or word");

==> tagainijisho_0.9.4.orig.tar.gz: tagainijisho-0.9.4/3rdparty/JMdictDescs.cc <==
QT_TRANSLATE_NOOP("JMdictLongDescs", "martial arts term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "rude or X-rated term (not displayed in educational software)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "abbreviation");
QT_TRANSLATE_NOOP("JMdictLongDescs", "adjective (keiyoushi)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "adjectival nouns or quasi-adjectives (keiyodoshi)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "nouns which may take the genitive case particle `no'");
QT_TRANSLATE_NOOP("JMdictLongDescs", "pre-noun adjectival (rentaishi)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "`taru' adjective");
QT_TRANSLATE_NOOP("JMdictLongDescs", "noun or verb acting prenominally");
QT_TRANSLATE_NOOP("JMdictLongDescs", "former adjective classification (being removed)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "adverb (fukushi)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "adverb taking the `to' particle");
QT_TRANSLATE_NOOP("JMdictLongDescs", "archaism");
QT_TRANSLATE_NOOP("JMdictLongDescs", "ateji (phonetic) reading");
QT_TRANSLATE_NOOP("JMdictLongDescs", "auxiliary");
QT_TRANSLATE_NOOP("JMdictLongDescs", "auxiliary verb");
QT_TRANSLATE_NOOP("JMdictLongDescs", "auxiliary adjective");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Buddhist term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "chemistry term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "children's language");
QT_TRANSLATE_NOOP("JMdictLongDescs", "colloquialism");
QT_TRANSLATE_NOOP("JMdictLongDescs", "computer terminology");
QT_TRANSLATE_NOOP("JMdictLongDescs", "conjunction");
QT_TRANSLATE_NOOP("JMdictLongDescs", "counter");
QT_TRANSLATE_NOOP("JMdictLongDescs", "derogatory");
QT_TRANSLATE_NOOP("JMdictLongDescs", "exclusively kanji");
QT_TRANSLATE_NOOP("JMdictLongDescs", "exclusively kana");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Expressions (phrases, clauses, etc.)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "familiar language");
QT_TRANSLATE_NOOP("JMdictLongDescs", "female term or language");
QT_TRANSLATE_NOOP("JMdictLongDescs", "food term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "geometry term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "gikun (meaning as reading)  or jukujikun (special kanji reading)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "honorific or respectful (sonkeigo) language");
QT_TRANSLATE_NOOP("JMdictLongDescs", "humble (kenjougo) language");
QT_TRANSLATE_NOOP("JMdictLongDescs", "word containing irregular kanji usage");
QT_TRANSLATE_NOOP("JMdictLongDescs", "idiomatic expression");
QT_TRANSLATE_NOOP("JMdictLongDescs", "word containing irregular kana usage");
QT_TRANSLATE_NOOP("JMdictLongDescs", "interjection (kandoushi)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "irregular okurigana usage");
QT_TRANSLATE_NOOP("JMdictLongDescs", "irregular verb");
QT_TRANSLATE_NOOP("JMdictLongDescs", "linguistics terminology");
QT_TRANSLATE_NOOP("JMdictLongDescs", "manga slang");
QT_TRANSLATE_NOOP("JMdictLongDescs", "male term or language");
QT_TRANSLATE_NOOP("JMdictLongDescs", "male slang");
QT_TRANSLATE_NOOP("JMdictLongDescs", "mathematics");
QT_TRANSLATE_NOOP("JMdictLongDescs", "military");
QT_TRANSLATE_NOOP("JMdictLongDescs", "noun (common) (futsuumeishi)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "adverbial noun (fukushitekimeishi)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "noun, used as a suffix");
QT_TRANSLATE_NOOP("JMdictLongDescs", "noun, used as a prefix");
QT_TRANSLATE_NOOP("JMdictLongDescs", "noun (temporal) (jisoumeishi)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "numeric");
QT_TRANSLATE_NOOP("JMdictLongDescs", "word containing out-dated kanji");
QT_TRANSLATE_NOOP("JMdictLongDescs", "obsolete term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "obscure term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "out-dated or obsolete kana usage");
QT_TRANSLATE_NOOP("JMdictLongDescs", "onomatopoeic or mimetic word");
QT_TRANSLATE_NOOP("JMdictLongDescs", "pronoun");
QT_TRANSLATE_NOOP("JMdictLongDescs", "poetical term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "polite (teineigo) language");
QT_TRANSLATE_NOOP("JMdictLongDescs", "prefix");
QT_TRANSLATE_NOOP("JMdictLongDescs", "proverb");
QT_TRANSLATE_NOOP("JMdictLongDescs", "particle");
QT_TRANSLATE_NOOP("JMdictLongDescs", "physics terminology");
QT_TRANSLATE_NOOP("JMdictLongDescs", "rare");
QT_TRANSLATE_NOOP("JMdictLongDescs", "sensitive");
QT_TRANSLATE_NOOP("JMdictLongDescs", "slang");
QT_TRANSLATE_NOOP("JMdictLongDescs", "suffix");
QT_TRANSLATE_NOOP("JMdictLongDescs", "word usually written using kanji alone");
QT_TRANSLATE_NOOP("JMdictLongDescs", "word usually written using kana alone");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Ichidan verb");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb with 'u' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Yodan verb with `hu/fu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Yodan verb with `ru' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb (not completely classified)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb - -aru special class");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `bu' ending");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `gu' ending");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `ku' ending");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb - Iku/Yuku special class");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `mu' ending");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `nu' ending");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `ru' ending");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `ru' ending (irregular verb)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `su' ending");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `tsu' ending");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `u' ending");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb with `u' ending (special class)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Godan verb - Uru old class verb (old form of Eru)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Ichidan verb - zuru verb (alternative form of -jiru verbs)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "intransitive verb");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Kuru verb - special class");
QT_TRANSLATE_NOOP("JMdictLongDescs", "irregular nu verb");
QT_TRANSLATE_NOOP("JMdictLongDescs", "irregular ru verb, plain form ends with -ri");
QT_TRANSLATE_NOOP("JMdictLongDescs", "noun or participle which takes the aux. verb suru");
QT_TRANSLATE_NOOP("JMdictLongDescs", "su verb - precursor to the modern suru");
QT_TRANSLATE_NOOP("JMdictLongDescs", "suru verb - special class");
QT_TRANSLATE_NOOP("JMdictLongDescs", "suru verb - irregular");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Kyoto-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Osaka-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Kansai-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Kantou-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Tosa-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Touhoku-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Tsugaru-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Kyuushuu-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Ryuukyuu-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nagano-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Hokkaido-ben");
QT_TRANSLATE_NOOP("JMdictLongDescs", "transitive verb");
QT_TRANSLATE_NOOP("JMdictLongDescs", "vulgar expression or word");
QT_TRANSLATE_NOOP("JMdictLongDescs", "`kari' adjective (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "`ku' adjective (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "`shiku' adjective (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "archaic/formal form of na-adjective");
QT_TRANSLATE_NOOP("JMdictLongDescs", "proper noun");
QT_TRANSLATE_NOOP("JMdictLongDescs", "verb unspecified");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Yodan verb with `ku' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Yodan verb with `gu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Yodan verb with `su' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Yodan verb with `tsu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Yodan verb with `nu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Yodan verb with `bu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Yodan verb with `mu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (upper class) with `ku' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (upper class) with `gu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (upper class) with `tsu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (upper class) with `dzu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (upper class) with `hu/fu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (upper class) with `bu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (upper class) with `mu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (upper class) with `yu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (upper class) with `ru' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (lower class) with `ku' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (lower class) with `gu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (lower class) with `su' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (lower class) with `zu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (lower class) with `tsu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (lower class) with `dzu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (lower class) with `nu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (lower class) with `hu/fu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (lower class) with `bu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (lower class) with `mu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (lower class) with `yu' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (lower class) with `ru' ending (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Nidan verb (lower class) with `u' ending and `we' conjugation (archaic)");
QT_TRANSLATE_NOOP("JMdictLongDescs", "architecture term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "astronomy, etc. term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "baseball term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "biology term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "botany term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "business term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "economics term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "engineering term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "finance term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "geology, etc. term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "law, etc. term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "medicine, etc. term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "music term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "Shinto term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "sports term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "sumo term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "zoology term");
QT_TRANSLATE_NOOP("JMdictLongDescs", "jocular, humorous term");
